Index: webrtc/p2p/base/portinterface.h |
diff --git a/webrtc/p2p/base/portinterface.h b/webrtc/p2p/base/portinterface.h |
index e73861965e538e0ab8e09907d56b63241547c4b7..32b039a23f42f81f218902eb2d5ef364f21c92ca 100644 |
--- a/webrtc/p2p/base/portinterface.h |
+++ b/webrtc/p2p/base/portinterface.h |
@@ -66,10 +66,11 @@ class PortInterface { |
virtual Connection* GetConnection( |
const rtc::SocketAddress& remote_addr) = 0; |
// Creates a new connection to the given address. |
enum CandidateOrigin { ORIGIN_THIS_PORT, ORIGIN_OTHER_PORT, ORIGIN_MESSAGE }; |
- virtual Connection* CreateConnection( |
- const Candidate& remote_candidate, CandidateOrigin origin) = 0; |
+ virtual Connection* CreateConnection(const Candidate& remote_candidate, |
+ CandidateOrigin origin, |
+ const IceConfig& config) = 0; |
// Functions on the underlying socket(s). |
virtual int SetOption(rtc::Socket::Option opt, int value) = 0; |
@@ -66,10 +66,11 @@ class PortInterface { |
virtual Connection* GetConnection( |
const rtc::SocketAddress& remote_addr) = 0; |
- // Creates a new connection to the given address. |
+ // Creates a new connection to the given address with the given ICE config. |
enum CandidateOrigin { ORIGIN_THIS_PORT, ORIGIN_OTHER_PORT, ORIGIN_MESSAGE }; |